from enum import Enum, auto
from zempy.zosapi.core.enum_base import ZosEnumBase

class AnalysisIDM(ZosEnumBase):
    XXXTemplateXXX = auto()
    RayFan = auto()
    OpticalPathFan = auto()
    PupilAberrationFan = auto()
    FieldCurvatureAndDistortion = auto()
    FocalShiftDiagram = auto()
    GridDistortion = auto()
    LateralColor = auto()
    LongitudinalAberration = auto()
    RayTrace = auto()
    SeidelCoefficients = auto()
    SeidelDiagram = auto()
    ZernikeAnnularCoefficients = auto()
    ZernikeCoefficientsVsField = auto()
    ZernikeFringeCoefficients = auto()
    ZernikeStandardCoefficients = auto()
    FftMtf = auto()
    FftThroughFocusMtf = auto()
    GeometricThroughFocusMtf = auto()
    GeometricMtf = auto()
    FftMtfMap = auto()
    GeometricMtfMap = auto()
    FftSurfaceMtf = auto()
    FftMtfvsField = auto()
    GeometricMtfvsField = auto()
    HuygensMtfvsField = auto()
    HuygensMtf = auto()
    HuygensSurfaceMtf = auto()
    HuygensThroughFocusMtf = auto()
    FftPsf = auto()
    FftPsfCrossSection = auto()
    FftPsfLineEdgeSpread = auto()
    HuygensPsfCrossSection = auto()
    HuygensPsf = auto()
    DiffractionEncircledEnergy = auto()
    GeometricEncircledEnergy = auto()
    GeometricLineEdgeSpread = auto()
    ExtendedSourceEncircledEnergy = auto()
    SurfaceCurvatureCross = auto()
    SurfacePhaseCross = auto()
    SurfaceSagCross = auto()
    SurfaceCurvature = auto()
    SurfacePhase = auto()
    SurfaceSag = auto()
    StandardSpot = auto()
    ThroughFocusSpot = auto()
    FullFieldSpot = auto()
    MatrixSpot = auto()
    ConfigurationMatrixSpot = auto()
    RMSField = auto()
    RMSFieldMap = auto()
    RMSLambdaDiagram = auto()
    RMSFocus = auto()
    Foucault = auto()
    Interferogram = auto()
    WavefrontMap = auto()
    DetectorViewer = auto()
    Draw2D = auto()
    Draw3D = auto()
    ImageSimulation = auto()
    GeometricImageAnalysis = auto()
    IMABIMFileViewer = auto()
    GeometricBitmapImageAnalysis = auto()
    BitmapFileViewer = auto()
    LightSourceAnalysis = auto()
    PartiallyCoherentImageAnalysis = auto()
    ExtendedDiffractionImageAnalysis = auto()
    BiocularFieldOfViewAnalysis = auto()
    BiocularDipvergenceConvergence = auto()
    RelativeIllumination = auto()
    VignettingDiagramSettings = auto()
    FootprintSettings = auto()
    YYbarDiagram = auto()
    PowerFieldMapSettings = auto()
    PowerPupilMapSettings = auto()
    IncidentAnglevsImageHeight = auto()
    FiberCouplingSettings = auto()
    YNIContributions = auto()
    SagTable = auto()
    CardinalPoints = auto()
    DispersionDiagram = auto()
    GlassMap = auto()
    AthermalGlassMap = auto()
    InternalTransmissionvsWavelength = auto()
    DispersionvsWavelength = auto()
    GrinProfile = auto()
    GradiumProfile = auto()
    UniversalPlot1D = auto()
    UniversalPlot2D = auto()
    PolarizationRayTrace = auto()
    PolarizationPupilMap = auto()
    Transmission = auto()
    PhaseAberration = auto()
    TransmissionFan = auto()
    ParaxialGaussianBeam = auto()
    SkewGaussianBeam = auto()
    PhysicalOpticsPropagation = auto()
    BeamFileViewer = auto()
    ReflectionvsAngle = auto()
    TransmissionvsAngle = auto()
    AbsorptionvsAngle = auto()
    DiattenuationvsAngle = auto()
    PhasevsAngle = auto()
    RetardancevsAngle = auto()
    ReflectionvsWavelength = auto()
    TransmissionvsWavelength = auto()
    AbsorptionvsWavelength = auto()
    DiattenuationvsWavelength = auto()
    PhasevsWavelength = auto()


AnalysisIDM._NATIVE_PATH = "ZOSAPI.Analysis.AnalysisIDM"
AnalysisIDM._ALIASES_EXTRA = {}


__all__ = ["AnalysisIDM"]
