from zempy.zosapi.core.enum_base import ZosEnumBase

class DirectionOfRayTravel(ZosEnumBase):
    _NATIVE_PATH = "ZOSAPI.Editors.LDE.DirectionOfRayTravel"
    _ALIASES_EXTRA ={}

    FORWARD = 0
    REVERSE = 1