from pathlib import Path
from typing import Final

NET_HELPER_SUFFIX: Final[Path] = Path("ZOS-API") / "Libraries" / "ZOSAPI_NetHelper.dll"
ZOSAPI_DLL_NAME:  Final[str]  = "ZOSAPI.dll"
ZOSAPI_IF_DLL_NAME: Final[str] = "ZOSAPI_Interfaces.dll"

__all__ = ["NET_HELPER_SUFFIX", "ZOSAPI_DLL_NAME", "ZOSAPI_IF_DLL_NAME"]