from __future__ import annotations
from typing import Protocol,Optional, overload, TYPE_CHECKING
from zempy.zosapi.analysis.enums.analysis_idm import  AnalysisIDM


if TYPE_CHECKING:
    from zempy.zosapi.analysis.protocols.ia_ import IA_


class IAnalyses(Protocol):
    @property
    def NumberOfAnalyses(self) -> int: ...
    @overload
    def CloseAnalysis(self, index: int) -> bool: ...
    @overload
    def CloseAnalysis(self, analysis: IA_) -> bool: ...
    def CloseAnalysis(self, arg) -> bool: ...
    def Get_AnalysisAtIndex(self, index: int) -> Optional[IA_]: ...
    def New_Analysis(self, AnalysisType: AnalysisIDM) -> Optional[IA_]: ...
    def New_Analysis_SettingsFirst(self, AnalysisType: AnalysisIDM) -> Optional[IA_]: ...
