from enum import Enum
class TraceMethod(Enum):
    Normal_Unpolarized      = "Normal unpolarized"
    Direct_Unpolarized      = "Direct unpolarized"
    Normal_Polarized        = "Normal polarized"
    Direct_Polarized        = "Direct polarized"
    Normal_Polarized_Full   = "Normal polarized full"
    Direct_Polarized_Full   = "Direct polarized full"
