from zempy.zosapi.editors.protocols.solve.i_solve_aplanatic import ISolveAplanatic
from zempy.zosapi.editors.protocols.solve.i_solve_automatic import ISolveAutomatic
from zempy.zosapi.editors.protocols.solve.i_solve_center_of_curvature import ISolveCenterOfCurvature
from zempy.zosapi.editors.protocols.solve.i_solve_chief_ray_angle import ISolveChiefRayAngle
from zempy.zosapi.editors.protocols.solve.i_solve_chief_ray_height import ISolveChiefRayHeight
from zempy.zosapi.editors.protocols.solve.i_solve_chief_ray_normal import ISolveChiefRayNormal
from zempy.zosapi.editors.protocols.solve.i_solve_cocentric_radius import ISolveCocentricRadius
from zempy.zosapi.editors.protocols.solve.i_solve_cocentric_surface import ISolveCocentricSurface
from zempy.zosapi.editors.protocols.solve.i_solve_compensator import ISolveCompensator
from zempy.zosapi.editors.protocols.solve.i_solve_config_pickup import ISolveConfigPickup
from zempy.zosapi.editors.protocols.solve.i_solve_duplicate_sag import ISolveDuplicateSag
from zempy.zosapi.editors.protocols.solve.i_solve_edge_thickness import ISolveEdgeThickness
from zempy.zosapi.editors.protocols.solve.i_solve_element_power import ISolveElementPower
from zempy.zosapi.editors.protocols.solve.i_solve_f_number import ISolveFNumber
from zempy.zosapi.editors.protocols.solve.i_solve_field_pickup import ISolveFieldPickup
from zempy.zosapi.editors.protocols.solve.i_solve_fixed import ISolveFixed
from zempy.zosapi.editors.protocols.solve.i_solve_invert_sag import ISolveInvertSag
from zempy.zosapi.editors.protocols.solve.i_solve_marginal_ray_angle import ISolveMarginalRayAngle
from zempy.zosapi.editors.protocols.solve.i_solve_marginal_ray_height import ISolveMarginalRayHeight
from zempy.zosapi.editors.protocols.solve.i_solve_marginal_ray_normal import ISolveMarginalRayNormal
from zempy.zosapi.editors.protocols.solve.i_solve_material_model import ISolveMaterialModel
from zempy.zosapi.editors.protocols.solve.i_solve_material_offset import ISolveMaterialOffset
from zempy.zosapi.editors.protocols.solve.i_solve_material_substitute import ISolveMaterialSubstitute
from zempy.zosapi.editors.protocols.solve.i_solve_maximum import ISolveMaximum
from zempy.zosapi.editors.protocols.solve.i_solve_none import ISolveNone
from zempy.zosapi.editors.protocols.solve.i_solve_object_pickup import ISolveObjectPickup
from zempy.zosapi.editors.protocols.solve.i_solve_optical_path_difference import ISolveOpticalPathDifference
from zempy.zosapi.editors.protocols.solve.i_solve_pickup_chief_ray import ISolvePickupChiefRay
from zempy.zosapi.editors.protocols.solve.i_solve_position import ISolvePosition
from zempy.zosapi.editors.protocols.solve.i_solve_pupil_position import ISolvePupilPosition
from zempy.zosapi.editors.protocols.solve.i_solve_surface_pickup import ISolveSurfacePickup
from zempy.zosapi.editors.protocols.solve.i_solve_thermal_pickup import ISolveThermalPickup
from zempy.zosapi.editors.protocols.solve.i_solve_variable import ISolveVariable
from zempy.zosapi.editors.protocols.solve.i_solve_zpl_macro import ISolveZPLMacro

__all__ = [
    "ISolveAplanatic",
    "ISolveAutomatic",
    "ISolveCenterOfCurvature",
    "ISolveChiefRayAngle",
    "ISolveChiefRayHeight",
    "ISolveChiefRayNormal",
    "ISolveCocentricRadius",
    "ISolveCocentricSurface",
    "ISolveCompensator",
    "ISolveConfigPickup",
    "ISolveDuplicateSag",
    "ISolveEdgeThickness",
    "ISolveElementPower",
    "ISolveFNumber",
    "ISolveFieldPickup",
    "ISolveFixed",
    "ISolveInvertSag",
    "ISolveMarginalRayAngle",
    "ISolveMarginalRayHeight",
    "ISolveMarginalRayNormal",
    "ISolveMaterialModel",
    "ISolveMaterialOffset",
    "ISolveMaterialSubstitute",
    "ISolveMaximum",
    "ISolveNone",
    "ISolveObjectPickup",
    "ISolveOpticalPathDifference",
    "ISolvePickupChiefRay",
    "ISolvePosition",
    "ISolvePupilPosition",
    "ISolveSurfacePickup",
    "ISolveThermalPickup",
    "ISolveVariable",
    "ISolveZPLMacro",
]
